Module index

Module index 

Modules

paths
Centralized index storage paths following XDG Base Directory Specification
state

Structs

IndexBuilder
SearchResult
Searcher
UpdatePlan
UpdateStats

Constants

CONFIRMATION_THRESHOLD
Threshold for prompting user confirmation before indexing. When encoding more than this many units, prompt the user unless auto_confirm is set.

Functions

bre_to_ere
Convert BRE (Basic Regular Expression) patterns to ERE (Extended Regular Expression).
escape_literal_braces
Escape literal braces that are not valid regex quantifiers.
index_exists
Check if an index exists for the given project
path_contains_ignored_dir
Check if a project root path contains an ignored directory in its path. This is used to provide better error messages when indexing fails. Returns Some(matched_pattern) if the path contains an ignored directory, None otherwise.