Module index
colgrep
1.1.2
Module index
Module Items
Modules
Structs
Constants
Functions
In crate colgrep
colgrep
Module
index
Modules

paths
Centralized index storage paths following XDG Base Directory Specification
state
Structs

Index
Builder
Search
Result
Searcher
Update
Plan
Update
Stats
Constants

CONFIRMATION_
THRESHOLD
Threshold for prompting user confirmation before indexing. When encoding more than this many units, prompt the user unless auto_confirm is set.
Functions

bre_
to_
ere
Convert BRE (Basic Regular Expression) patterns to ERE (Extended Regular Expression).
escape_
literal_
braces
Escape literal braces that are not valid regex quantifiers.
index_
exists
Check if an index exists for the given project
path_
contains_
ignored_
dir
Check if a project root path contains an ignored directory in its path. This is used to provide better error messages when indexing fails. Returns Some(matched_pattern) if the path contains an ignored directory, None otherwise.