pub struct IndexBuilder { /* private fields */ }Implementations
Sourceimpl IndexBuilder
impl IndexBuilder
pub fn new(project_root: &Path, model_path: &Path) -> Result<Self>
pub fn with_quantized( project_root: &Path, model_path: &Path, quantized: bool, ) -> Result<Self>
pub fn with_options( project_root: &Path, model_path: &Path, quantized: bool, pool_factor: Option<usize>, parallel_sessions: Option<usize>, batch_size: Option<usize>, ) -> Result<Self>
Sourcepub fn set_auto_confirm(&mut self, auto_confirm: bool)
pub fn set_auto_confirm(&mut self, auto_confirm: bool)
Set whether to automatically confirm indexing for large codebases (> 10K code units)
Sourcepub fn set_model_name(&mut self, name: &str)
pub fn set_model_name(&mut self, name: &str)
Set the model name for display purposes
Sourcepub fn index(
&mut self,
languages: Option<&[Language]>,
force: bool,
) -> Result<UpdateStats>
pub fn index( &mut self, languages: Option<&[Language]>, force: bool, ) -> Result<UpdateStats>
Single entry point for indexing.
- Creates index if none exists
- Updates incrementally if files changed
- Full rebuild if
force = true - Full rebuild if CLI version changed (clears outdated index)
Sourcepub fn try_index(
&mut self,
languages: Option<&[Language]>,
force: bool,
) -> Result<Option<UpdateStats>>
pub fn try_index( &mut self, languages: Option<&[Language]>, force: bool, ) -> Result<Option<UpdateStats>>
Non-blocking version of index() for use during search.
Returns Ok(None) immediately if another process holds the lock,
allowing the caller to search the existing index without waiting.
Sourcepub fn index_specific_files(&mut self, files: &[PathBuf]) -> Result<UpdateStats>
pub fn index_specific_files(&mut self, files: &[PathBuf]) -> Result<UpdateStats>
Index only specific files (for filtered search). Only indexes files that are not already in the index or have changed. Returns the number of files that were indexed.
Sourceimpl IndexBuilder
impl IndexBuilder